@@ -1,15 +1,13 @@
-#' Converts a data frame or matrix to a condformat_tbl class.
+#' Conditional formatting for data frames
 #'
-#' condformat_tbl objects allow to add conditional formatting information,
-#' that can be viewed when the condformat_tbl object is printed.
-#'
-#' They also have all properties from conventional data frames.
+#' A \code{condformat_tbl} object is a data frame with attributes regarding
+#' the formatting of their cells, that can be viewed when the \code{condformat_tbl}
+#' object is printed.
 #'
 #' @param x A matrix or data.frame
 #'
-#' @return The condformat_tbl object. This object can be used
-#'         in a ggplot-like syntax to apply conditional formatting
-#'         rules. It can also be used as a conventional
+#' @return The condformat_tbl object. This object can be piped to apply
+#'         conditional formatting rules. It can also be used as a conventional
 #'         data frame.
 #'
 #'         The condformat_tbl print method generates an htmlTable, to be
@@ -18,9 +16,9 @@
 #' data(iris)
 #' condformat(iris[1:5,])
 #'
-#' condformat(iris[1:5,]) + rule_fill_gradient(Sepal.Length)
+#' condformat(iris[1:5,]) %>% rule_fill_gradient(Sepal.Length)
 #'
-#' condformat(iris[1:5,]) +
+#' condformat(iris[1:5,]) %>%
 #'  rule_fill_discrete(Sepal.Length, expression=Sepal.Width > 2)
 #' @export
 condformat <- function(x) {
@@ -35,7 +33,9 @@ condformat <- function(x) {
 }
 
 
-#' Combines the data with the formatting rules and graphical options.
+#' Combines data with formatting rules (deprecated)
+#'
+#' This is deprecated
 #'
 #' @param x A condformat_tbl object
 #' @param obj A condformat_show or a condformat_rule object to be combined
@@ -47,6 +47,7 @@ condformat <- function(x) {
 #' @method + condformat_tbl
 #' @export
 "+.condformat_tbl" <- function(x, obj) {
+  #Deprecated
   if (inherits(obj, "condformat_show_columns")) {
     condformatopts <- attr(x, "condformat")
     condformatopts$show$cols <- c(condformatopts$show$cols, list(obj))
@@ -72,6 +73,11 @@ condformat <- function(x) {
   }
 }
 
+# Deprecated
 #' @importFrom lazyeval uq
 #' @export
-lazyeval::uq
+lazyeval::uq # D
+
+#' @importFrom magrittr %>%
+#' @export
+magrittr::`%>%`
