@@ -1,10 +1,9 @@
-
-#' Returns a matrix with the value of the CSS field for each element
-#' of our data frame.
-#'
-#' @param finalformat list with the css_fields
-#' @param field the name of the CSS field to be returned
-#' @return a matrix of size xview with the CSS field information
+# Returns a matrix with the value of the CSS field for each element
+# of our data frame.
+#
+# @param finalformat list with the css_fields
+# @param field the name of the CSS field to be returned
+# @return a matrix of size xview with the CSS field information
 get_css_field <- function(finalformat, field) {
   if (!(field %in% names(finalformat$css_fields))) {
     field_matrix <- matrix(data = "",
@@ -16,15 +15,15 @@ get_css_field <- function(finalformat, field) {
   return(field_matrix)
 }
 
-#' If rule_locks is TRUE, locks the cells specified by mask
-#' so no further rules modify them
-#'
-#' @param rule_locks a logical. If FALSE, lock_cells does nothing
-#' @param mask a logical matrix. TRUE if the cell is affected by the rule
-#' @param finalformat The finalformat list, with the format options
-#'
-#' @return finalformat, the list with format options
-#'
+# If rule_locks is TRUE, locks the cells specified by mask
+# so no further rules modify them
+#
+# @param rule_locks a logical. If FALSE, lock_cells does nothing
+# @param mask a logical matrix. TRUE if the cell is affected by the rule
+# @param finalformat The finalformat list, with the format options
+#
+# @return finalformat, the list with format options
+#
 lock_cells <- function(rule_locks, mask, finalformat) {
   if (identical(rule_locks, TRUE)) {
     finalformat$css_cell_unlocked[mask] <- FALSE
@@ -50,30 +49,32 @@ fill_css_field_by_cols <- function(finalformat, field, values, columns, xview, l
 }
 
 parse_columns_and_expression_ <- function(columns, expression) {
+  # Deprecated
   if (is.factor(columns)) {
     columns <- as.character(columns)
   }
   if (is.character(expression)) {
     suggested_formula <- paste0("~ ", expression)
-    warning(
-      paste0("Deprecation: Using a character as expression is deprecated. ",
-             "It will not be supported in the future. Please use a formula instead. ",
-             "If you need help to build formulas programmatically, see the example ",
-             "in the help page. Suggestion: expression=", suggested_formula))
     expression <- stats::as.formula(suggested_formula)
   }
 
-  if (!lazyeval::is_formula(expression)) {
+  if (!lazyeval::is_formula(expression)) { # D
     expression <- as.factor(expression)
   }
 
-  if (lazyeval::is_formula(expression) &&
-      identical(lazyeval::f_rhs(expression), as.name("."))) {
+  if (lazyeval::is_formula(expression) && # D
+      identical(lazyeval::f_rhs(expression), as.name("."))) { # D
     if (length(columns) > 1) {
-      warning("rule_fill_discrete_ applied to multiple variables, using the first given variable as expression")
+      warning("rule applied to multiple columns, using the first given variable as expression")
     }
-    lazyeval::f_rhs(expression) <- as.name(columns[1])
+    lazyeval::f_rhs(expression) <- as.name(columns[1]) # D
   }
   return(list(columns = columns, expression = expression))
 }
 
+add_rule_to_condformat <- function(x, rule) {
+  condformatopts <- attr(x, "condformat")
+  condformatopts$rules <- c(condformatopts$rules, list(rule))
+  attr(x, "condformat") <- condformatopts
+  x
+}
